/*
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */


#ifndef TASKMANAGERENGINEWRITER_H
#define TASKMANAGERENGINEWRITER_H

#include <in_sock.h>

class CTaskManagerEngineWriter : public CActive
{
public: // new methods

	static CTaskManagerEngineWriter* NewL( RSocket& aSocket );
	
	static CTaskManagerEngineWriter* NewLC( RSocket& aSocket );

	~CTaskManagerEngineWriter();
	
	void DoWriteL( const TDesC& aData );
	
protected: // from CActive

	void DoCancel();
	
	void RunL();
	
private: // private methods
	
	CTaskManagerEngineWriter( RSocket& aSocket );
	
	void ConstructL();
	
	void SendNextPacket();
	
private: // member variables

	enum 
	{
		KWriteBufferSize = 20
	};
	
	enum TWriterState
	{
		EWaiting = 0,
		ESending
	};

	RSocket& iSocket;
	
	// data waiting to be sent
	TBuf8<KWriteBufferSize> iTransferBuffer;

	// data being written to socket
	TBuf8<KWriteBufferSize> iWriteBuffer;
	
	TWriterState iState;
};

#endif
