/*
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 *    
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *    
 *  * Redistributions of source code must retain the above copyright notice, this
 *    list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of Nokia Corporation nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *    IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *    DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *    SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 *    CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *    OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *    
 *    Description:  
 */


// INCLUDE FILES
#include "TaskManagerConnInfo.h"
#include "TaskManager.pan"

// CONSTANTS
const TInt TTaskManagerConnInfo::KDefaultPort = 3000;

// ================= MEMBER FUNCTIONS =======================

// constructor
TTaskManagerConnInfo::TTaskManagerConnInfo(): iPort( KDefaultPort ), iIap(0)
	{
	// No implementation
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::SetServerAddress()
// Sets the server address.
// ----------------------------------------------------------
//
void TTaskManagerConnInfo::SetServerAddress( const TDesC& aAddress )
	{
	if( aAddress.Length() > KMaxServerNameLength )
		{
		Panic(ETaskManagerServerAddressTooLong);
		}
	iServerAddress.Copy( aAddress );
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::ServerAddress()
// Gets the server address.
// ----------------------------------------------------------
//
TBufC< KMaxServerNameLength > TTaskManagerConnInfo::ServerAddress() const
	{
	return iServerAddress;
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::SetPort()
// Sets the port number.
// ----------------------------------------------------------
//	
void TTaskManagerConnInfo::SetPort( const TInt aPort )
	{
	iPort = aPort;
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::Port()
// Gets the port number.
// ----------------------------------------------------------
//	
const TInt TTaskManagerConnInfo::Port() const
	{
	return iPort;
	}
	
// ----------------------------------------------------------
// TTaskManagerConnInfo::SetUsername()
// Sets the username.
// ----------------------------------------------------------
//		
void TTaskManagerConnInfo::SetUsername( const TDesC& aUsername )
	{
	if( aUsername.Length() > KMaxUsernameLength )
		{
		Panic(ETaskManagerUsernameTooLong); 
		}
	iUsername.Copy( aUsername );
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::Username()
// Gets the username.
// ----------------------------------------------------------
//		
TBufC< KMaxUsernameLength > TTaskManagerConnInfo::Username() const
	{
	return iUsername;	
	}
	
// ----------------------------------------------------------
// TTaskManagerConnInfo::SetPassword()
// Sets the password.
// ----------------------------------------------------------
//			
void TTaskManagerConnInfo::SetPassword( const TDesC& aPassword )
	{
	if( aPassword.Length() > KMaxPasswordLength )
		{
		Panic(ETaskManagerPasswordTooLong);
		}
	iPassword.Copy( aPassword );
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::Password()
// Gets the password.
// ----------------------------------------------------------
//		
TBufC< KMaxPasswordLength > TTaskManagerConnInfo::Password() const
	{
	return iPassword;	
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::SetIap()
// Sets the IAP.
// ----------------------------------------------------------
//			
void TTaskManagerConnInfo::SetIap( const TUint32& aId)
	{
	iIap = aId;
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::Iap()
// Gets the IAP.
// ----------------------------------------------------------
//			
TUint32 TTaskManagerConnInfo::Iap() const
	{
	return iIap;
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::ExternalizeL()
// Saves the connection data to the given stream.
// ----------------------------------------------------------
//		
void TTaskManagerConnInfo::ExternalizeL(RWriteStream& aStream) const
	{
	aStream << iServerAddress;
	aStream.WriteInt32L(iPort);
	aStream << iUsername;
	aStream << iIap;
	}

// ----------------------------------------------------------
// TTaskManagerConnInfo::InternalizeL()
// Reads the connections data from the given stream.
// ----------------------------------------------------------
//			
void TTaskManagerConnInfo::InternalizeL(RReadStream& aStream)
	{
	aStream >> iServerAddress;
	iPort  = aStream.ReadInt32L();
	aStream >> iUsername;
	aStream >> iIap;
	}
	
// End of file
